@@ -91,6 +91,7 @@ def get_user(
 def request_adaboard(
     path: str,
     method=requests.get,
+    omit_content_type: bool = False,
     **kwargs,
 ) -> requests.models.Response:
     """Function to hit the adaboard api at the specified url and raise for error on response.
@@ -112,9 +113,10 @@ def request_adaboard(
 
     headers = {
         "authorization": f"Bearer {adaboard_token['access_token']}",
-        "Content-Type": "application/json",
         "Accept": "application/json",
     }
+    if not omit_content_type:
+        headers["Content-Type"] = "application/json"
 
     request_url = build_request_url(path)
 
