@@ -3,13 +3,16 @@
 from .apps import (
     delete_app,
     deploy_app,
+    deploy_multicontainer_app,
     edit_app,
+    edit_multicontainer_app,
     get_all_apps,
     get_app,
     get_app_id,
     get_app_logs,
     get_apps_by_author,
     get_apps_status,
+    get_container_idx,
     restart_app,
     start_app,
     stop_app,
@@ -18,13 +21,16 @@ from .apps import (
 __all__ = [
     "delete_app",
     "deploy_app",
+    "deploy_multicontainer_app",
     "edit_app",
+    "edit_multicontainer_app",
     "get_all_apps",
     "get_app",
     "get_app_id",
     "get_app_logs",
     "get_apps_by_author",
     "get_apps_status",
+    "get_container_idx",
     "restart_app",
     "start_app",
     "stop_app",
