@@ -1,7 +1,6 @@
 "The Cards sub-package exposes the core integrations of the cards in the AdaLab Gallery."
 
 from .cards import (
-    approve_card,
     create_card,
     create_card_group,
     create_url_card,
@@ -9,7 +8,6 @@ from .cards import (
     delete_card,
     delete_card_group,
     delete_url_subtype,
-    deregister_as_reviewer,
     edit_card,
     edit_card_group,
     edit_url_card,
@@ -23,13 +21,12 @@ from .cards import (
     get_url_subtypes,
     hide_card,
     launch_card,
-    register_as_reviewer,
     set_card_visibility,
     toggle_card_favorite,
+    toggle_card_review,
 )
 
 __all__ = [
-    "approve_card",
     "create_card",
     "create_card_group",
     "create_url_card",
@@ -37,7 +34,6 @@ __all__ = [
     "delete_card",
     "delete_card_group",
     "delete_url_subtype",
-    "deregister_as_reviewer",
     "edit_card",
     "edit_card_group",
     "edit_url_card",
@@ -51,8 +47,8 @@ __all__ = [
     "get_cards",
     "hide_card",
     "launch_card",
-    "register_as_reviewer",
     "set_card_visibility",
     "toggle_card_favorite",
+    "toggle_card_review",
 ]
 __title__ = "adalib Cards"
