@@ -2,7 +2,7 @@ import base64
 import json
 import os
 import re
-from typing import Union
+from typing import Optional, Union
 
 import requests
 
@@ -129,7 +129,8 @@ def create_card(  # noqa: C901
         # Check file size before actually pulling it from the Lab
         try:
             response_props = adaboard.request_adaboard(
-                path=f"jupyter/files/notebook/content/?path={os.path.dirname(notebook_file)}"
+                path="jupyter/files/notebook/content/",
+                params={"path": os.path.dirname(notebook_file)},
             ).json()
             props = [
                 x
@@ -144,7 +145,8 @@ def create_card(  # noqa: C901
             props["size"] <= MAX_FILE_SIZE
         ), f"Notebook file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
         nb_file_bin = adaboard.request_adaboard(
-            path=f"jupyter/files/notebook/content/fetch?path={notebook_file}",
+            path="jupyter/files/notebook/content/fetch",
+            params={"path": notebook_file},
         ).json()["content"]
     else:
         # Check file size before actually opening it
@@ -186,7 +188,8 @@ def create_card(  # noqa: C901
                 # Directories end with "/"; otherwise they are considered files; no nesting allowed
                 if aux_file["source"].endswith("/"):
                     dir_cont = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={aux_file['source']}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": aux_file["source"]},
                     ).json()
                     dir_paths = [
                         {
@@ -200,7 +203,8 @@ def create_card(  # noqa: C901
                     all_aux_files.extend(dir_paths)
                 else:
                     response_props = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={os.path.dirname(aux_file['source'])}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": os.path.dirname(aux_file["source"])},
                     ).json()
                     file_path = [
                         {
@@ -220,7 +224,8 @@ def create_card(  # noqa: C901
                 ), f"Auxiliary file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
                 # "content" is the binary; "content_name" determines the target folder
                 aux_file_bin = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/fetch?path={aux_file['source']}",
+                    path="jupyter/files/notebook/content/fetch",
+                    params={"path": aux_file["source"]},
                 ).json()["content"]
                 aux_file_name = f"{aux_file['target']}{os.path.basename(aux_file['source'])}"
                 tmp = {
@@ -829,7 +834,8 @@ def edit_card(  # noqa: C901
             # Check file size before actually pulling it from the Lab
             try:
                 response_props = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/?path={os.path.dirname(notebook_file)}"
+                    path="jupyter/files/notebook/content/",
+                    params={"path": os.path.dirname(notebook_file)},
                 ).json()
                 props = [
                     x
@@ -844,7 +850,8 @@ def edit_card(  # noqa: C901
                 props["size"] <= MAX_FILE_SIZE
             ), f"Notebook file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
             nb_file_bin = adaboard.request_adaboard(
-                path=f"jupyter/files/notebook/content/fetch?path={notebook_file}",
+                path="jupyter/files/notebook/content/fetch",
+                params={"path": notebook_file},
             ).json()["content"]
         else:
             # Check file size before actually opening it
@@ -884,7 +891,8 @@ def edit_card(  # noqa: C901
                 # Directories end with "/"; otherwise they are considered files; no nesting allowed
                 if aux_file["source"].endswith("/"):
                     dir_cont = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={aux_file['source']}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": aux_file["source"]},
                     ).json()
                     dir_paths = [
                         {
@@ -898,7 +906,8 @@ def edit_card(  # noqa: C901
                     all_aux_files.extend(dir_paths)
                 else:
                     response_props = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={os.path.dirname(aux_file['source'])}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": os.path.dirname(aux_file["source"])},
                     ).json()
                     file_path = [
                         {
@@ -918,7 +927,8 @@ def edit_card(  # noqa: C901
                 ), f"Auxiliary file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
                 # "content" is the binary; "content_name" determines the target folder
                 aux_file_bin = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/fetch?path={aux_file['source']}",
+                    path="jupyter/files/notebook/content/fetch",
+                    params={"path": aux_file["source"]},
                 ).json()["content"]
                 aux_file_name = f"{aux_file['target']}{os.path.basename(aux_file['source'])}"
                 tmp = {
@@ -1406,7 +1416,15 @@ def expose_card(card_id: int) -> None:
     return None
 
 
-def get_cards(card_type: str = "all") -> list[list[int | str]]:
+def get_cards(
+    card_type: str = "all",
+    url_subtype: str = "all",
+    head: Optional[int] = None,
+    search_phrase: Optional[str] = None,
+    group_category: Optional[str] = None,
+    only_hidden: bool = False,
+    only_exposed: bool = False,
+) -> list[list[int | str | bool]]:
     """
     Gets all cards registered in the Gallery.
 
@@ -1418,39 +1436,97 @@ def get_cards(card_type: str = "all") -> list[list[int | str]]:
     :return: a list with the main info of all cards in the Gallery
     :rtype: list
     """
-    card_types = [
-        x.get("key")
+    card_types = {
+        x["key"]: [x["cardtype_id"]]
         for x in adaboard.request_adaboard(path="cardtypes").json()
+    }
+    card_types["all"] = None
+    allowed_groups = [
+        "favorited",
+        "authored",
+        "coauthored",
+        "owned",
+        "reviewed",
+        "unreviewed",
+        "approved",
+        "reviewer",
+        "involved",
     ]
-    card_types.append("all")
+
+    assert not (
+        card_type != "url" and url_subtype != "all"
+    ), """The 'url_subtype' parameter is only available when 'card_type' is set to 'url'."""
+    url_subtypes = {
+        x["name"]: [x["urlcardsubtype_id"]]
+        for x in adaboard.request_adaboard(
+            "url-card-subtypes", method=requests.get
+        ).json()
+    }
+    url_subtypes["all"] = None
     assert (
         card_type in card_types
-    ), f"Card type must be one of {', '.join(card_types)}"
-    all_cards = adaboard.get_all_pages(api_url="cards")
+    ), f"Card type must be one of {', '.join(card_types.keys())}"
+    assert (
+        url_subtype in url_subtypes
+    ), f"URL subtype must be one of {', '.join(url_subtypes.keys())}"
+    if head is not None:
+        assert (
+            1 <= head <= 100
+        ), "The 'head' parameter must be between 1 and 100."
+
+    filter_options = {"url_subtypes": url_subtypes[url_subtype]}
+    if url_subtype == "all":
+        filter_options = {"cardtypes": card_types[card_type]}
+
+    if search_phrase is not None:
+        filter_options["phrase"] = search_phrase
+
+    if group_category is not None:
+        assert (
+            group_category in allowed_groups
+        ), f"Group category must be one of {', '.join(allowed_groups)}"
+        filter_options["groups"] = [group_category]
+
+    if only_hidden:
+        filter_options["visibility"] = [True]
+
+    if only_exposed:
+        filter_options["visibility"] = [False]
+
+    if head is None:
+        all_cards = adaboard.get_all_pages(
+            api_url="cards",
+            params={"filter_options": json.dumps(filter_options)},
+        )
+    else:
+        all_cards = adaboard.request_adaboard(
+            "cards",
+            params={
+                "filter_options": json.dumps(filter_options),
+                "size": head,
+            },
+        ).json()["items"]
 
-    if card_type == "all":
-        return [
-            [
-                x.get("card_id"),
-                x.get("cardtype").get("key"),
-                x.get("name"),
-                x.get("author").get("name"),
-            ]
-            for x in all_cards
-        ]
     return [
         [
             x.get("card_id"),
             x.get("cardtype").get("key"),
+            (x.get("url_subtype", dict()) or dict()).get("name"),
+            x.get("reviewed"),
+            not x.get("hidden"),
             x.get("name"),
+            ", ".join(
+                [str(x["card_id"]) for x in (x.get("card_group_cards") or [])]
+            ),
             x.get("author").get("name"),
         ]
         for x in all_cards
-        if x.get("cardtype").get("key") == card_type
     ]
 
 
-def get_card_contents(card_id: int) -> dict[str, Union[str, list[dict]]]:
+def get_card_contents(
+    card_id: int, incl_content: bool = False
+) -> dict[str, Union[str, list[dict]]]:
     """
     Gets the contents of a specific card in the Gallery.
 
@@ -1462,20 +1538,48 @@ def get_card_contents(card_id: int) -> dict[str, Union[str, list[dict]]]:
     :rtype: dict
     """
 
-    response = adaboard.request_adaboard(path=f"cards/{card_id}").json()
+    response = adaboard.request_adaboard(
+        path=f"cards/{card_id}", params={"incl_content": incl_content}
+    ).json()
 
     return_struct = {
-        "card_author": response.get("author").get("name"),
-        "card_name": response.get("name"),
-        "description": response.get("description"),
-        "card_type": response.get("cardtype").get("key"),
-        "contents": [],
+        "Author": response.get("author").get("name"),
+        "Owner": response.get("owner").get("name"),
+        "Co-Authors": [x.get("name") for x in response.get("coauthors")],
+        "Card Type": response.get("cardtype").get("key"),
+        "Name": response.get("name"),
+        "Description": response.get("description"),
+        "Keywords": [x["keyword"] for x in response.get("keywords")],
+        "Exposed": not response["hidden"],
+        "Reviewed": response["reviewed"],
+        "Created at": response.get("created_date"),
+        "Updated at": response.get("updated_date"),
+        "Reviewers": [x.get("name") for x in response.get("reviewers")],
+        "Reviewers Completed": [
+            x.get("name") for x in response.get("reviewers_complete")
+        ],
+        "URL": response.get("remote_url"),
+        "URL type": (response.get("url_subtype") or dict()).get("name"),
+        "Cards in Group": [
+            x.get("card_id") for x in response.get("card_group_cards")
+        ],
+        "Kernel ID": (response.get("card_kernel") or dict()).get(
+            "metadata_id"
+        ),
+        "# Launches": response.get("usage_count").get("usage_count"),
+        "Contents": [],
+        "Permissions - Allowed to Launch": response.get("permissions").get(
+            "allowed_delete"
+        ),
+        "Permissions - Allowed to Edit": response.get("permissions").get(
+            "allowed_edit"
+        ),
     }
 
     for contents in response.get("content"):
         content = base64.b64decode(contents.get("content"))
         contents["content"] = content
-        return_struct.get("contents").append(contents)
+        return_struct.get("Contents").append(contents)
 
     return return_struct
 
@@ -1630,7 +1734,7 @@ def launch_card(
     # Get the main Notebook
     nb_path = card_path[card_path.find("/gallery") + 1 :]
     response = adaboard.request_adaboard(
-        path=f"jupyter/files/notebook/content/fetch?path={nb_path}"
+        path="jupyter/files/notebook/content/fetch", params={"path": nb_path}
     ).json()
     nb_file_dict = json.loads(
         base64.b64decode(response["content"]).decode("utf-8")
