@@ -207,37 +207,14 @@ def create_image_metadata(
         }
 
     # Push image from a source to a target repo in Harbor
-    response_pusher = adaboard.request_adaboard(
+    adaboard.request_adaboard(
         path="script_runner/runs/start/", method=requests.post, json=payload
     ).json()
 
-    # Update metadata object in AdaLab
-    payload = {
-        "name": response_metadata["name"],
-        "description": response_metadata["description"],
-        "startup_cmd": response_metadata["startup_cmd"],
-        "run_id": response_pusher["id"],
-    }
-
-    adaboard.request_adaboard(
-        path=f"registry/metadata/{response_metadata['metadata_id']}",
-        method=requests.put,
-        json=payload,
-    )
-
-    # Update image state in AdaLab to the one in Harbor
-    adaboard.request_adaboard(
-        path=f"registry/metadata/{response_metadata['metadata_id']}/ready",
-        method=requests.put,
-    ).json()
-
-    # Get image metadata from AdaLab
-    response = adaboard.request_adaboard(
+    return adaboard.request_adaboard(
         path=f"registry/metadata/{response_metadata['metadata_id']}",
     ).json()
 
-    return response
-
 
 def edit_image_metadata(
     metadata_id: int,
@@ -316,11 +293,11 @@ def get_all_metadata(
     :rtype: list
     """
     response = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=false",
+        path="registry/metadata", params={"get_archived": False}
     ).json()
     if include_archived:
         res_archived = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=true",
+            path="registry/metadata", params={"get_archived": True}
         ).json()
         response.extend(res_archived)
 
@@ -426,10 +403,10 @@ def get_image_metadata_id(
 
     # Get metadata for all images
     response = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=false",
+        path="registry/metadata", params={"get_archived": False}
     ).json()
     res_archived = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=true",
+        path="registry/metadata", params={"get_archived": True}
     ).json()
     response.extend(res_archived)
 
@@ -514,11 +491,11 @@ def get_projects(include_archived: bool = False) -> list[str]:
     """
 
     response = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=false",
+        path="registry/metadata", params={"get_archived": False}
     ).json()
     if include_archived:
         res_archived = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=true",
+            path="registry/metadata", params={"get_archived": True}
         ).json()
         response.extend(res_archived)
 
@@ -550,10 +527,10 @@ def get_publish_logs(
     # Get run ID of the publishing process
     try:
         mdata = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=false",
+            path="registry/metadata", params={"get_archived": False}
         ).json()
         mdata_archived = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=true",
+            path="registry/metadata", params={"get_archived": True}
         ).json()
         mdata.extend(mdata_archived)
         publish_id = [
@@ -607,11 +584,11 @@ def get_repositories_by_author(
     """
 
     response = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=false",
+        path="registry/metadata", params={"get_archived": False}
     ).json()
     if include_archived:
         res_archived = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=true",
+            path="registry/metadata", params={"get_archived": True}
         ).json()
         response.extend(res_archived)
 
@@ -642,11 +619,11 @@ def get_repositories_by_type(
     ), f"Can only get repositories of the type {', '.join([x for x in ALLOWED_METADATA_TYPES])}"
 
     response = adaboard.request_adaboard(
-        path="registry/metadata?get_archived=false",
+        path="registry/metadata", params={"get_archived": False}
     ).json()
     if include_archived:
         res_archived = adaboard.request_adaboard(
-            path="registry/metadata?get_archived=true",
+            path="registry/metadata", params={"get_archived": True}
         ).json()
         response.extend(res_archived)
 
