@@ -7,6 +7,7 @@ from .lab import (
     delete_files,
     download_file,
     get_available_kernels,
+    get_build_logs,
     get_build_status,
     get_config_options,
     get_installed_kernels,
@@ -29,6 +30,7 @@ __all__ = [
     "download_file",
     "delete_files",
     "get_available_kernels",
+    "get_build_logs",
     "get_build_status",
     "get_config_options",
     "get_installed_kernels",
