@@ -357,7 +357,7 @@ def download_file(file_path: str, target_path: str) -> None:
 
     # Get the file, base64 encoded
     response = adaboard.request_adaboard(
-        path=f"jupyter/files/notebook/content/fetch?path={file_path}",
+        path="jupyter/files/notebook/content/fetch", params={"path": file_path}
     ).json()
 
     # Decode the file to get the binary
@@ -536,7 +536,7 @@ def get_lab_files(path: str) -> list[dict[str, str | int]]:
     """
 
     response = adaboard.request_adaboard(
-        path=f"jupyter/files/notebook/content/?path={path}"
+        path="jupyter/files/notebook/content/", params={"path": path}
     ).json()
 
     return response
@@ -580,7 +580,7 @@ def get_lab_logs(
         source in ALLOWED_LAB_LOG_SOURCES
     ), f"Log source must be one of {', '.join([x for x in ALLOWED_LAB_LOG_SOURCES])}"
 
-    params = f"?&system={LOG_SOURCES[source]}"
+    params = {"system": LOG_SOURCES[source]}
     # Check that the date format is correct
     if from_date:
         try:
@@ -589,7 +589,7 @@ def get_lab_logs(
             raise AssertionError(
                 "Date must be in ISO format (YYYY-MM-DDTHH:mm:ss+HH:mm)."
             )
-        params += f"&start_dt={from_date}"
+        params["start_dt"] = from_date
 
     if to_date:
         try:
@@ -598,10 +598,10 @@ def get_lab_logs(
             raise AssertionError(
                 "Date must be in ISO format (YYYY-MM-DDTHH:mm:ss+HH:mm)."
             )
-        params += f"&end_dt={to_date}"
+        params["end_dt"] = to_date
 
     response = adaboard.request_adaboard(
-        path=f"jupyter/server/v2/logs{params}"
+        path="jupyter/server/v2/logs", params=params
     ).json()
 
     return response
@@ -627,7 +627,8 @@ def get_lab_status(metrics: bool = True, options: bool = True) -> dict[
     """
 
     response = adaboard.request_adaboard(
-        path=f"jupyter/server?metrics={metrics}&options={options}"
+        path="jupyter/server",
+        params={"metrics": metrics, "options": options},
     ).json()
 
     return response
@@ -699,28 +700,6 @@ def move_file(old_path: str, new_path: str) -> None:
     return None
 
 
-def _start_lab(options: list[int] = []) -> None:
-    """
-    Start the user's Lab environment with the specified configuration options.
-
-    :param options: IDs for the desired values of Lab configuration options (tip: check available options with "lab.get_config_options")
-    :type options: list
-    :return: nothing
-    :rtype: None
-    """
-
-    payload = {"options": options}
-    response = adaboard.request_adaboard(
-        path="jupyter/server", method=requests.post, json=payload
-    ).json()
-
-    assert (
-        response["message"] == "OK"
-    ), "The Lab environment could not be started."
-
-    return None
-
-
 def stop_lab() -> None:
     """
     Stop the user's Lab environment.
