@@ -174,7 +174,7 @@ def create_schedule(
     content = {}
     if card_id:
         tmp = adaboard.request_adaboard(
-            f"cards/{card_id}?incl_content=true"
+            f"cards/{card_id}", params={"incl_content": True}
         ).json()
         content["content"] = tmp["content"]
     else:
@@ -182,7 +182,8 @@ def create_schedule(
             # Check file size before actually pulling it from the Lab
             try:
                 response_props = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/?path={os.path.dirname(notebook_file)}"
+                    path="jupyter/files/notebook/content/",
+                    params={"path": os.path.dirname(notebook_file)},
                 ).json()
                 props = [
                     x
@@ -197,7 +198,8 @@ def create_schedule(
                 props["size"] <= MAX_FILE_SIZE
             ), f"Notebook file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
             nb_file_bin = adaboard.request_adaboard(
-                path=f"jupyter/files/notebook/content/fetch?path={notebook_file}",
+                path="jupyter/files/notebook/content/fetch",
+                params={"path": notebook_file},
             ).json()["content"]
         else:
             # Check file size before actually opening it
@@ -224,7 +226,8 @@ def create_schedule(
                 # Directories end with "/"; otherwise they are considered files; no nesting allowed
                 if aux_file["source"].endswith("/"):
                     dir_cont = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={aux_file['source']}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": aux_file["source"]},
                     ).json()
                     dir_paths = [
                         {
@@ -238,7 +241,8 @@ def create_schedule(
                     all_aux_files.extend(dir_paths)
                 else:
                     response_props = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={os.path.dirname(aux_file['source'])}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": os.path.dirname(aux_file["source"])},
                     ).json()
                     file_path = [
                         {
@@ -258,7 +262,8 @@ def create_schedule(
                 ), f"Auxiliary file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
                 # "content" is the binary; "content_name" determines the target folder
                 aux_file_bin = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/fetch?path={aux_file['source']}",
+                    path="jupyter/files/notebook/content/fetch",
+                    params={"path": aux_file["source"]},
                 ).json()["content"]
                 aux_file_name = f"{aux_file['target']}{os.path.basename(aux_file['source'])}"
                 tmp = {
@@ -504,7 +509,9 @@ def edit_schedule(  # noqa: C901
 
     # Fetch old configuration
     tmp = adaboard.request_adaboard(
-        f"schedules/v2/{schedule_id}?with_content=true", method=requests.get
+        f"schedules/v2/{schedule_id}",
+        method=requests.get,
+        params={"with_content": True},
     ).json()
     tmp.pop("kernel")
     tmp.pop("owner")
@@ -643,7 +650,8 @@ def edit_schedule(  # noqa: C901
             # Check file size before actually pulling it from the Lab
             try:
                 response_props = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/?path={os.path.dirname(notebook_file)}"
+                    path="jupyter/files/notebook/content/",
+                    params={"path": os.path.dirname(notebook_file)},
                 ).json()
                 props = [
                     x
@@ -658,7 +666,8 @@ def edit_schedule(  # noqa: C901
                 props["size"] <= MAX_FILE_SIZE
             ), f"Notebook file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
             nb_file_bin = adaboard.request_adaboard(
-                path=f"jupyter/files/notebook/content/fetch?path={notebook_file}",
+                path="jupyter/files/notebook/content/fetch",
+                params={"path": notebook_file},
             ).json()["content"]
         else:
             # Check file size before actually opening it
@@ -697,7 +706,8 @@ def edit_schedule(  # noqa: C901
                 # Directories end with "/"; otherwise they are considered files; no nesting allowed
                 if aux_file["source"].endswith("/"):
                     dir_cont = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={aux_file['source']}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": aux_file["source"]},
                     ).json()
                     dir_paths = [
                         {
@@ -711,7 +721,8 @@ def edit_schedule(  # noqa: C901
                     all_aux_files.extend(dir_paths)
                 else:
                     response_props = adaboard.request_adaboard(
-                        path=f"jupyter/files/notebook/content/?path={os.path.dirname(aux_file['source'])}"
+                        path="jupyter/files/notebook/content/",
+                        params={"path": os.path.dirname(aux_file["source"])},
                     ).json()
                     file_path = [
                         {
@@ -731,7 +742,8 @@ def edit_schedule(  # noqa: C901
                 ), f"Auxiliary file size exceeds the maximum allowed ({MAX_FILE_SIZE} bytes). Please reduce the size of the file and try again."
                 # "content" is the binary; "content_name" determines the target folder
                 aux_file_bin = adaboard.request_adaboard(
-                    path=f"jupyter/files/notebook/content/fetch?path={aux_file['source']}",
+                    path="jupyter/files/notebook/content/fetch",
+                    params={"path": aux_file["source"]},
                 ).json()["content"]
                 aux_file_name = f"{aux_file['target']}{os.path.basename(aux_file['source'])}"
                 tmp = {
