@@ -1,8 +1,10 @@
 """The utils sub-package includes some non-API related functionalities in AdaLab."""
 
 from .acl import validate_acl
+from .volumes import validate_volume_mount
 
 __all__ = [
     "validate_acl",
+    "validate_volume_mount",
 ]
 __title__ = "adalib utils"
