@@ -4,7 +4,7 @@ from typing import Literal
 
 
 def validate_acl(
-    obj: Literal["app", "card", "schedule"],
+    obj: Literal["app", "card", "schedule", "volume"],
     allow_none: bool = False,
     *acls: list[str],
 ):
@@ -17,9 +17,10 @@ def validate_acl(
     :raises AssertionError: If the ACLs are invalid
     """
     allowed_acls = {
-        "app": ["public", "private", "userlist", "group"],
+        "app": ["public", "logged_in", "userlist", "grouplist"],
         "card": ["public", "logged_in", "userlist", "grouplist"],
         "schedule": ["public", "logged_in", "userlist", "grouplist"],
+        "volume": ["public", "logged_in", "userlist", "grouplist"],
     }
 
     assert obj in allowed_acls, f"Object does not support ACL: {obj}"
